"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.newBinCommand = void 0;
var tslib_1 = require("tslib");
var ora_1 = tslib_1.__importDefault(require("ora"));
var fs_extra_1 = tslib_1.__importDefault(require("fs-extra"));
var utils_1 = require("../../shared/utils");
var scaffolding_helpers_1 = require("./scaffolding.helpers");
var new_1 = require("./setup/new");
var messages_1 = require("../../shared/messages");
var new_helpers_1 = require("./new.helpers");
var templateOptions = Object.keys(new_1.newSetup);
exports.newBinCommand = function (prog) {
    prog
        .command('new <pkg> [dir]')
        .describe('Create new project')
        .alias('n')
        .example('new projectName')
        .option('t, template', "Specify a template.\n     Available templates: [" + templateOptions.join(', ') + "]\n     \n     ", 'cra')
        .example("new projectName --template " + templateOptions[0])
        .action(function (name, dir, _a) {
        var template = _a.template;
        return tslib_1.__awaiter(void 0, void 0, void 0, function () {
            var bootSpinner, projectName, projectDir, author, templateConfig, packageJsonPreset, err_1, preparingSpinner;
            return tslib_1.__generator(this, function (_b) {
                switch (_b.label) {
                    case 0:
                        bootSpinner = ora_1.default();
                        return [4 /*yield*/, new_helpers_1.getProjectName({
                                dir: dir,
                                name: name,
                                onFailure: function (message) { return tslib_1.__awaiter(void 0, void 0, void 0, function () {
                                    return tslib_1.__generator(this, function (_a) {
                                        bootSpinner.fail(message);
                                        return [2 /*return*/];
                                    });
                                }); }
                            })];
                    case 1:
                        projectName = _b.sent();
                        projectDir = new_helpers_1.getProjectDir({
                            dir: dir,
                            name: projectName
                        });
                        bootSpinner.start(messages_1.newMessage.creating(projectDir));
                        _b.label = 2;
                    case 2:
                        _b.trys.push([2, 6, , 7]);
                        if (fs_extra_1.default.existsSync(projectDir)) {
                            throw new Error(messages_1.newMessage.exists(projectDir));
                        }
                        return [4 /*yield*/, scaffolding_helpers_1.copyTemplate({ dir: projectDir, bin: 'new', template: template })];
                    case 3:
                        _b.sent();
                        bootSpinner.stop();
                        return [4 /*yield*/, scaffolding_helpers_1.getAuthor()];
                    case 4:
                        author = _b.sent();
                        scaffolding_helpers_1.setNpmAuthorName(author);
                        bootSpinner.start();
                        process.chdir(projectDir);
                        templateConfig = new_1.newSetup[template];
                        packageJsonPreset = tslib_1.__assign(tslib_1.__assign({}, templateConfig.packageJson), { name: projectName, author: author });
                        return [4 /*yield*/, scaffolding_helpers_1.createPackageJson({
                                dir: projectDir,
                                preset: packageJsonPreset
                            })];
                    case 5:
                        _b.sent();
                        bootSpinner.succeed(messages_1.newMessage.created({
                            dir: projectDir,
                            name: projectName
                        }));
                        return [3 /*break*/, 7];
                    case 6:
                        err_1 = _b.sent();
                        bootSpinner.fail(messages_1.newMessage.failed(projectName));
                        utils_1.logError(err_1);
                        process.exit(1);
                        return [3 /*break*/, 7];
                    case 7:
                        preparingSpinner = ora_1.default(messages_1.newMessage.preparing()).start();
                        try {
                            scaffolding_helpers_1.sortPackageJson();
                            utils_1.installDependencies();
                            preparingSpinner.succeed(messages_1.newMessage.prepared());
                        }
                        catch (err) {
                            preparingSpinner.fail(messages_1.newMessage.failedPreparation());
                            utils_1.logError(err);
                        }
                        console.log(messages_1.newMessage.finish(projectDir));
                        return [2 /*return*/];
                }
            });
        });
    });
};
